.. :changelog:

Changelog
---------

0.4.0 (2018-07-19)
++++++++++++++++++

* Add support for Python 2.7 and PyPy.
* Get icon size for New York Times (`#9 <https://github.com/scottwernervt/favicon/issues/9>`_)

0.3.0 (2018-05-18)
++++++++++++++++++

* Fav icon not found for microsoft.com (`#5 <https://github.com/scottwernervt/favicon/issues/7>`_)

0.2.0 (2018-05-17)
++++++++++++++++++

* Handle poor html values in links (`#5 <https://github.com/scottwernervt/favicon/issues/5>`_)
* Use given website for icon url scheme (`#6 <https://github.com/scottwernervt/favicon/issues/6>`_)

0.1.0 (2018-05-07)
++++++++++++++++++

* First release.